/*
 * @Author: zc
 * @description 数据统计-中心统计
 */
import request from '@/utils/request';
import qs from "qs";
/**
 * @description 中心报表统计
 * @param {object} params
 */
export const centerReport = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/center_report_forms_statistics`,
    method: 'get',
    params,
  });
}
/**
 * @description 高频来电统计
 * @param {object} params
 */
export const departmentHighFrequency = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/high_frequency_call_statistics`,
    method: 'get',
    params,
  });
}
/**
 * @description 高频来电统计详情
 * @param {object} params
 */
export const departmentHighFrequencyDetail = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/high_frequency_call_statistics_order_list`,
    method: 'get',
    params,
  });
}
/**
 * @description 高频事件统计
 * @param {object} params
 */
export const departmentHighFrequencyEvent = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/highmatter-warning`,
    method: 'get',
    params,
  });
}
/**
 * @description 高频事件统计明细
 * @param {object} params
 */
export const departmentHighFrequencyEventDetail = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/highmatter-warning-detail`,
    method: 'get',
    params,
    paramsSerializer: (params:any) => qs.stringify(params)
  });
}
/**
 * @description 市州互转-转入
 * @param {object} params
 */
export const cityConversionIn = (params: object) => {
  return request({
    url: `/api/v1/TranspondCity/order_receive_in_list`,
    method: 'get',
    params,
  });
}
/**
 * @description 市州互转-转出
 * @param {object} params
 */
export const cityConversionOut = (params: object) => {
  return request({
    url: `/api/v1/TranspondCity/order_transfer_out_list`,
    method: 'get',
    params,
  });
}
/**
 * @description 回退错件统计
 * @param {object} params
 */
export const centerReturnError = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/reTransact`,
    method: 'get',
    params,
  });
}
/**
 * @description 回退错件统计导出
 * @param {object} data
 */
export const centerReturnErrorExport = (data: object) => {
  return request({
    url: `/api/v1/BiOrder/reTransact/_export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}
/**
 * @description 回退错件统计明细
 * @param {object} params
 */
export const centerReturnErrorDetail = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/reTransact_detail`,
    method: 'get',
    params,
  });
}
/**
 * @description 回退错件统计明细导出
 * @param {object} data
 */
export const centerReturnErrorDetailExport = (data: object) => {
  return request({
    url: `/api/v1/BiOrder/reTransact_detail/_export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}
/**
 * @description 回退错件统计明细基础信息
 * @param {object} params
 */
export const centerReturnErrorDetailBase = (params?: object) => {
  return request({
    url: `/api/v1/BiOrder/reTransact_base`,
    method: 'get',
    params,
  });
}
/**
 * @description 应急清单
 * @param {object} params
 */
export const centerEmergencyList = (params: object) => {
  return request({
    url: `/api/v1/ContingencyManagement/getlist`,
    method: 'get',
    params,
  });
}
/**
 * @description 应急清单导出
 * @param {object} data
 */
export const centerEmergencyListExport = (data: object) => {
  return request({
    url: `/api/v1/ContingencyManagement/getlist_export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}
/**
 * @description 新增分析报告
 * @param {object} data
 */
export const centerAddAnalysisReport = (data: object) => {
  return request({
    url: `/api/v1/Order/analysis`,
    method: 'post',
    data,
  });
}
/**
 * @description 删除分析报告
 * @param {object} data
 */
export const centerDeleteAnalysisReport = (data: object) => {
  return request({
    url: `/api/v1/Order/analysis`,
    method: 'delete',
    data,
  });
}
/**
 * @description 分析报告列表
 * @param {object} params
 */
export const centerAnalysisReportList = (params: object) => {
  return request({
    url: `/api/v1/Order/analysis_list`,
    method: 'get',
    params,
  });
}
/**
 * @description 分析报告明细
 * @param {object} params
 */
export const centerAnalysisReportDetail = (params: object) => {
  return request({
    url: `/api/v1/Order/analysis_detail`,
    method: 'get',
    params,
  });
}
/**
 * @description 生成分析报告
 * @param {object} params
 */
export const centerGenerateAnalysisReport = (params: object) => {
  return request({
    url: `/api/v1/Order/analysis_report`,
    method: 'get',
    params,
  });
}
/**
 * @description 甄别申请统计
 * @param {object} params
 */
export const centerDifferentiateApply = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/screen-apply`,
    method: 'get',
    params,
  });
}
/**
 * @description 甄别申请统计导出
 * @param {object} data
 */
export const centerDifferentiateApplyExport = (data: object) => {
  return request({
    url: `/api/v1/BiOrder/screen-apply-export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}
/**
 * @description 甄别审批统计
 * @param {object} params
 */
export const centerDifferentiateApproval = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/screen-audit`,
    method: 'get',
    params,
  });
}
/**
 * @description 甄别审批统计导出
 * @param {object} data
 */
export const centerDifferentiateApprovalExport = (data: object) => {
  return request({
    url: `/api/v1/BiOrder/screen-audit-export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}
/**
 * @description 未签收统计
 * @param {object} params
 */
export const centerUnreceived = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/get_order_nosigen`,
    method: 'get',
    params,
  });
}
/**
 * @description 未签收统计导出
 * @param {object} data
 */
export const centerUnreceivedExport = (data: object) => {
  return request({
    url: `/api/v1/BiOrder/get_order_nosigen_export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}
/**
 * @description 未签收统计明细
 * @param {object} params
 */
export const centerUnreceivedDetail = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/get_order_nosigen_detail`,
    method: 'get',
    params,
  });
}
/**
 * @description 未签收统计明细导出
 * @param {object} data
 */
export const centerUnreceivedDetailExport = (data: object) => {
  return request({
    url: `/api/v1/BiOrder/get_order_nosigen_detail_export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}
/**
 * @description 回访来源统计
 * @param {object} params
 */
export const centerReturnVisitSource = (params: object) => {
  return request({
    url: `/api/v1/Order/visit/source`,
    method: 'get',
    params,
  });
}
/**
 * @description 回访来源统计导出
 * @param {object} data
 */
export const centerReturnVisitSourceExport = (data: object) => {
  return request({
    url: `/api/v1/Order/visit/source/export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}
/**
 * @description 企业专席信件统计
 * @param {object} params
 */
export const centerEnterpriseSpecialistLetter = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/get_enterprise_seats_report`,
    method: 'get',
    params,
  });
}
/**
 * @description 企业专席信件统计导出
 * @param {object} data
 */
export const centerEnterpriseSpecialistLetterExport = (data: object) => {
  return request({
    url: `/api/v1/BiOrder/get_enterprise_seats_report_export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}
/**
 * @description 企业专席信件统计明细
 * @param {object} params
 */
export const centerEnterpriseSpecialistLetterDetail = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/get_enterprise_seats_report_detail`,
    method: 'get',
    params,
  });
}
/**
 * @description 企业专席信件统计明细导出
 * @param {object} data
 */
export const centerEnterpriseSpecialistLetterDetailExport = (data: object) => {
  return request({
    url: `/api/v1/BiOrder/get_enterprise_seats_report_detail_export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}
/**
 * @description 发布量统计图表
 * @param {object} params
 */
export const centerPublish = (params: object) => {
  return request({
    url: `/api/v1/Order/published/statistics`,
    method: 'get',
    params,
  });
};
/**
 * @description 发布量统计列表（部门）
 * @param {object} params
 */
export const centerPublishList = (params: object) => {
  return request({
    url: `/api/v1/Order/published/statistics/department`,
    method: 'get',
    params,
  });
};
/**
 * @description 发布量统计列表导出（部门）
 * @param {object} data
 */
export const centerPublishListExport = (data: object) => {
  return request({
    url: `/api/v1/Order/published/statistics/department/export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
};
/**
 * @description 发布量统计列表（用户）
 * @param {object} params
 */
export const centerPublishUserList = (params: object) => {
  return request({
    url: `/api/v1/Order/published/statistics/user`,
    method: 'get',
    params,
  });
};
/**
 * @description 发布量统计列表导出（用户）
 * @param {object} data
 */
export const centerPublishUserListExport = (data: object) => {
  return request({
    url: `/api/v1/Order/published/statistics/user/export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
};
/**
 * @description 数据清单基础数据
 * @param {object} params
 */
export const centerDataListBasicData = (params?: object) => {
  return request({
    url: `/api/v1/BiOrder/order-data-inventory-basedata`,
    method: 'get',
    params,
  });
};
/**
 * @description 数据清单基础数据列表
 * @param {object} params
 */
export const centerDataLis = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/order-data-inventory`,
    method: 'get',
    params,
  });
};
/**
 * @description 数据清单基础数据列表导出
 * @param {object} data
 */
export const centerDataListExport = (data: object) => {
  return request({
    url: `/api/v1/BiOrder/order-data-inventory-export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
};
/**
 * @description 中心受理统计
 * @param {object} params
 */
export const centerAccept = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/center-accept`,
    method: 'get',
    params,
  });
}
/**
 * @description 中心受理统计导出
 * @param {object} data
 */
export const centerAcceptExport = (data: object) => {
  return request({
    url: `/api/v1/BiOrder/center-accept-export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}
/**
 * @description 中心受理值班坐席统计
 * @param {object} params
 */
export const centerAcceptDuty = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/center-accept-user`,
    method: 'get',
    params,
  });
}
/**
 * @description 中心受理值班坐席统计导出
 * @param {object} data
 */
export const centerAcceptDutyExport = (data: object) => {
  return request({
    url: `/api/v1/BiOrder/center-accept-user-export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}
/**
 * @description 中心受理值班时间段
 * @param {object} params
 */
export const centerAcceptDutyTime = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/center-accept-hour`,
    method: 'get',
    params,
  });
}
/**
 * @description 中心受理值班时间段导出
 * @param {object} data
 */
export const centerAcceptDutyTimeExport = (data: object) => {
  return request({
    url: `/api/v1/BiOrder/center-accept-hour-export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}