/*
 * @Description: 常量管理
 */

import dayjs from 'dayjs';

/**
 * 常用时间选择
 */
export const shortcuts = [
	{
		text: '今天',
		value: () => {
			const end = new Date();
			const start = new Date();
			// 今天的开始时间
			start.setHours(0);
			start.setMinutes(0);
			start.setSeconds(0);
			// 今天的结束时间
			end.setHours(23);
			end.setMinutes(59);
			end.setSeconds(59);
			return [start, end];
		},
	},
	{
		text: '近一周',
		value: () => {
			const end = new Date();
			const start = new Date();
			// 今天的开始时间
			start.setHours(0);
			start.setMinutes(0);
			start.setSeconds(0);
			// 今天的结束时间
			end.setHours(23);
			end.setMinutes(59);
			end.setSeconds(59);
			start.setTime(start.getTime() - 3600 * 1000 * 24 * 7);
			return [start, end];
		},
	},
	{
		text: '近一个月',
		value: () => {
			const end = new Date();
			const start = new Date();
			// 今天的开始时间
			start.setHours(0);
			start.setMinutes(0);
			start.setSeconds(0);
			// 今天的结束时间
			end.setHours(23);
			end.setMinutes(59);
			end.setSeconds(59);
			start.setTime(start.getTime() - 3600 * 1000 * 24 * 30);
			return [start, end];
		},
	},
	{
		text: '上季度',
		value: () => {
			let oDate = new Date();
			let prevMonth = oDate.getMonth() - 3;
			const end = new Date();
			const start = new Date();
			start.setMonth(prevMonth);
			start.setDate(1);
			start.setHours(0);
			start.setMinutes(0);
			start.setSeconds(0);
			end.setMonth(prevMonth + 3);
			end.setDate(0);
			end.setHours(23);
			end.setMinutes(59);
			end.setSeconds(59);
			return [start, end];
		},
	},
	{
		text: '本季度',
		value: () => {
			const end = new Date();
			const start = new Date();
			start.setMonth(Math.floor(new Date().getMonth() / 3) * 3);
			start.setDate(1);
			start.setHours(0);
			start.setMinutes(0);
			start.setSeconds(0);
			end.setMonth(Math.floor(new Date().getMonth() / 3) * 3 + 3);
			end.setDate(0);
			end.setHours(23);
			end.setMinutes(59);
			end.setSeconds(59);
			return [start, end];
		},
	},
	{
		text: '去年',
		value: () => {
			let oDate = new Date();
			let prevYear = oDate.getFullYear() - 1;
			const end = new Date();
			const start = new Date();
			start.setFullYear(prevYear);
			start.setMonth(0);
			start.setDate(1);
			end.setFullYear(prevYear);
			end.setMonth(11);
			end.setDate(31);
			// 今天的开始时间
			start.setHours(0);
			start.setMinutes(0);
			start.setSeconds(0);
			// 今天的结束时间
			end.setHours(23);
			end.setMinutes(59);
			end.setSeconds(59);
			return [start, end];
		},
	},
	{
		text: '今年',
		value: () => {
			const end = new Date();
			const start = new Date();
			start.setMonth(0);
			start.setDate(1);
			// 今天的开始时间
			start.setHours(0);
			start.setMinutes(0);
			start.setSeconds(0);
			// 今天的结束时间
			end.setHours(23);
			end.setMinutes(59);
			end.setSeconds(59);
			return [start, end];
		},
	},
];

/**
 * @description 常用意见
 * @param  {number}  Seat 坐席  1
 * @param  {number}  Rest 休息  2
 * @param  {number} OrderCirculation 工单流转  3
 * @param  {number} KnowledgeL 知识库  4
 * @param  {number} RestReason 休息原因  5
 * @param  {number} HandleAgain 办理意见  6
 * @param  {number} Supervise 督办意见  7
 * @param  {number} Return 退回意见  8
 * @param  {number} Archive 归档意见  9
 * @param  {number} Teti 特提  10
 * @param  {number} Discriminate 甄别  11
 * @param  {number} ReturnVisit 回访  12
 * @param  {number} Delay 延期  13
 */
export const commonEnum = {
	Seat: 1,
	Rest: 2,
	OrderCirculation: 3,
	KnowledgeL: 4,
	RestReason: 5,
	HandleAgain: 6,
	Supervise: 7,
	Return: 8,
	Archive: 9,
	Teti: 10,
	Discriminate: 11,
	ReturnVisit: 12,
	Delay: 13,
};

// 获取当前时间（日志打印专用）
export const getNowDateTime = () => {
	return dayjs().format('YYYY-MM-DD HH:mm:ss');
};
// 限制日期选择最大时间
export const disabledDate = (time: Date) => {
	return time.getTime() < new Date().getTime();
};

// 默认选择日期
export const defaultDate = [dayjs().startOf('day').format('YYYY-MM-DD'), dayjs().endOf('day').format('YYYY-MM-DD')];
// 默认选择日期
export const defaultDateOneMonth = [	dayjs().startOf('day').subtract(1, 'month').format('YYYY-MM-DD'),
	dayjs().endOf('day').format('YYYY-MM-DD'),];
// 默认选择日期时间
export const defaultDateTime = [dayjs().startOf('day').format('YYYY-MM-DD[T]HH:mm:ss'), dayjs().endOf('day').format('YYYY-MM-DD[T]HH:mm:ss')];
// 默认选择日期(近三个月)
export const defaultDateThree = [
	dayjs().startOf('day').subtract(3, 'month').format('YYYY-MM-DD[T]HH:mm:ss'),
	dayjs().endOf('day').format('YYYY-MM-DD[T]HH:mm:ss'),
];
// 默认选择日期(近一个月)
export const defaultDateOne = [
	dayjs().startOf('day').subtract(1, 'month').format('YYYY-MM-DD[T]HH:mm:ss'),
	dayjs().endOf('day').format('YYYY-MM-DD[T]HH:mm:ss'),
];
// 默认的起始与结束时刻 （Start date time 00:00:00, end date time 23:59:59）
// @ts-ignore
export const defaultTimeStartEnd: [Date, Date] = [new Date(2000, 1, 1, 0, 0, 0), new Date(2000, 2, 1, 23, 59, 59)]; // '00:00:00', '23:59:59'
